

/*
   This is a header file for gd font, generated using
   bdftogd version 0.5 by Jan Pazdziora, adelton@fi.muni.cz
   from bdf font
   -misc-fixed-bold-r-normal-sans-13-94-100-100-c-70-iso8859-2
   at Thu Jan  8 13:54:57 1998.
   No copyright info was found in the original bdf.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "gdfontmb.h"

char gdFontMediumBoldData[] = {
	/* Char 0 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 1 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 2 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 3 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 4 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 5 */
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 1, 0,
	0, 0, 1, 1, 0, 1, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 6 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 7 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 8 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 9 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 10 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 11 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 12 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 13 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 14 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 15 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 16 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 17 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 18 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 19 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 20 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 21 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 22 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 23 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 24 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 25 */
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 26 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 27 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 28 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 29 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 30 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	1, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 31 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 32 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 33 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 34 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 35 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 0, 1, 0, 0,
	0, 0, 1, 0, 1, 0, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 0, 1, 0, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 0, 1, 0, 0,
	0, 0, 1, 0, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 36 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 0, 1, 1, 0, 1, 0,
	1, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 1, 0,
	1, 0, 1, 1, 0, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 37 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 0, 0, 1, 0,
	1, 0, 1, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 1, 0, 1, 0,
	1, 0, 0, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 38 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 0, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 0, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 39 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 40 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 41 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 42 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 43 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 44 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 45 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 46 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 47 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 48 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 49 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	1, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 50 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 51 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 52 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 53 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 54 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 55 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 56 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 57 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 58 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 59 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 60 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 61 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 62 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 63 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 64 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 0, 0, 0, 1, 1, 0,
	1, 0, 1, 1, 1, 1, 0,
	1, 0, 1, 0, 1, 1, 0,
	1, 0, 1, 1, 1, 1, 0,
	1, 0, 0, 0, 0, 0, 0,
	1, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 65 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 66 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 67 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 68 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 69 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 70 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 71 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 72 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 73 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 74 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 75 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 76 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 77 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 0, 0, 0, 0, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 78 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 79 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 80 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 81 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 82 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 83 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 84 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 85 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 86 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 87 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 0, 0, 0, 0, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 88 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 0, 0, 0, 0, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 0, 0, 0, 0, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 89 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 90 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 91 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 92 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 93 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 94 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 0, 0, 0, 0, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 95 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 96 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 97 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 98 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 99 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 100 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 101 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 102 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 103 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,

	/* Char 104 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 105 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 106 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,

	/* Char 107 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 108 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 109 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 110 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 111 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 112 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,

	/* Char 113 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,

	/* Char 114 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 115 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 116 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 117 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 118 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 119 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 120 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 121 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,

	/* Char 122 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 123 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 124 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 125 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 126 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 127 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 128 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 129 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 130 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 131 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 132 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 133 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 134 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 135 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 136 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 137 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 138 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 139 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 140 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 141 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 142 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 143 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 144 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 145 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 146 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 147 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 148 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 149 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 150 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 151 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 152 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 153 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 154 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 155 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 156 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 157 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 158 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 159 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 160 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 161 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,

	/* Char 162 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 163 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 164 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 165 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 166 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 167 */
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 168 */
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 169 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 170 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,

	/* Char 171 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 172 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 173 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 174 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 175 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 176 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 177 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,

	/* Char 178 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,

	/* Char 179 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 1, 0,
	0, 0, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 180 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 181 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 182 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 183 */
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 184 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 0, 0, 0,

	/* Char 185 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 186 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,

	/* Char 187 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 188 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 189 */
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 1, 1,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 190 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 191 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 192 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 193 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 194 */
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 195 */
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 196 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 197 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 198 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 199 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,

	/* Char 200 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 201 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 202 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,

	/* Char 203 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 204 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 205 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 206 */
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 207 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 208 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 209 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 210 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 211 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 212 */
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 213 */
	0, 1, 1, 0, 0, 1, 1,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 214 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 215 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 216 */
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 217 */
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 218 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 219 */
	0, 1, 1, 0, 0, 1, 1,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 220 */
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 221 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 222 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,

	/* Char 223 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 0, 1, 1, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 224 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 225 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 226 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 227 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 228 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 229 */
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 230 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 231 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,

	/* Char 232 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 233 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 234 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 1, 1, 0, 0,

	/* Char 235 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 236 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 237 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 238 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 239 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 1, 1,
	0, 0, 0, 1, 1, 0, 1,
	0, 0, 0, 1, 1, 1, 0,
	0, 0, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	1, 1, 0, 1, 1, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 240 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 1, 1, 1, 1,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 241 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 242 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 243 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 244 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 245 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 1, 1,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 246 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 247 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 248 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 249 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 0, 0, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 250 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 251 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 1, 1,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 252 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,

	/* Char 253 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 1, 1, 1, 0,
	0, 1, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	1, 1, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 0, 0,

	/* Char 254 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	1, 1, 1, 1, 1, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,
	0, 1, 1, 0, 1, 1, 0,
	0, 0, 1, 1, 1, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0,

	/* Char 255 */
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0,


};

gdFont gdFontMediumBoldRep = {
	256,
	0,
	7,
	13,
	gdFontMediumBoldData
};

BGD_EXPORT_DATA_PROT gdFontPtr gdFontMediumBold = &gdFontMediumBoldRep;

/*
	Function: gdFontGetMediumBold
*/
BGD_DECLARE(gdFontPtr)
gdFontGetMediumBold (void)
{
	return gdFontMediumBold;
}

/* This file has not been truncated. */
